March 31, 2019.
Between London and Boston.

# SayTeX+ Design

Is the layered design a good idea, or can everything be captured by the formal grammar that I'm still not sure will even work?

It feels like that question will be hard to answer without knowledge of how the formal grammar system can work. Or maybe not. Consider the examples of converting spoken numbers into digital numbers -- representing that in a formal grammar would be tedious at best and impossible at worst. Upon further thought, maybe it indeed could work. But what would be the point of introducing that complexity when I already have a working version of the spoken number conversion, not using the formal grammar?

I guess the answer remains the same: I need to learn the specifics and the extent of the formal grammar. I do understand how a formal grammar is defined, what I do not understand is how to create the parse tree from it. How to invert the process? And that, I must learn. Dr. Keane has advised me to used Wolfram Language's built-in grammar system, and I should explore that option, but I do not think it will be a feasible option. We will see.

Hmmm. I have no Wi-Fi. Can I do anything now? I can think again about how to properly leave all SayTeX Syntax as-is, while still interpreting its relevant semantical properties.

Hmmm. I do feel like everything should be able to be incorporated into the parse tree, including the spoken number conversion. The layering I am thinking of is implicit in the parse tree, which is partly what makes it so useful.

Meh, I can't really do anything right now. Sad.